Manual of CLI options
=====================

mbrs-generate
~~~~~~~~~~~~~

.. argparse::
    :module: mbrs.cli.generate
    :func: format_argparser
    :prog: mbrs-generate

mbrs-decode
~~~~~~~~~~~

.. argparse::
    :module: mbrs.cli.decode
    :func: format_argparser
    :prog: mbrs-decode

mbrs-score
~~~~~~~~~~

.. argparse::
    :module: mbrs.cli.score
    :func: format_argparser
    :prog: mbrs-score
